# InvoiceResponse


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**process_id** | **str** | The Id of the process that handle the operation.  | [optional] 
**request_id** | **str** | Unique request identifier. If you need to contact us about a specific request, providing the request identifier will ensure the fastest possible resolution.  | [optional] 
**reasons** | [**List[FailedReason]**](FailedReason.md) |  | [optional] 
**success** | **bool** | Indicates whether the call succeeded.  | [optional] 
**account_id** | **str** | The ID of the customer account associated with the invoice. | [optional] 
**adjustment_amount** | **decimal.Decimal** | The amount of the invoice adjustments associated with the invoice. | [optional] 
**amount** | **decimal.Decimal** | The total amount of the invoice. | [optional] 
**amount_without_tax** | **decimal.Decimal** | The invoice amount excluding tax. | [optional] 
**auto_pay** | **bool** | Whether invoices are automatically picked up for processing in the corresponding payment run. | [optional] 
**balance** | **decimal.Decimal** | The remaining balance of the invoice after all payments, adjustments and refunds are applied. | [optional] 
**bill_run_id** | **str** | The id of bill run if the invoice is generated by a bill run. | [optional] 
**bill_to_contact_id** | **str** | The ID of the bill-to contact associated with the invoice. | [optional] 
**bill_to_contact_snapshot_id** | **str** | The ID of the bill-to contact snapshot associated with the invoice. | [optional] 
**comments** | **str** | Comments about the invoice. | [optional] 
**created_by_id** | **str** | The user ID of the person who created the invoice. If a bill run generated the invoice, then the value is the user ID of person who created the bill run. | [optional] 
**created_date** | **str** | The date and time when the invoice was created, in &#x60;yyyy-mm-dd hh:mm:ss&#x60; format. For example, 2017-03-01 15:31:10. | [optional] 
**credit_balance_adjustment_amount** | **decimal.Decimal** | The currency amount of the adjustment applied to the customer&#39;s credit balance.   **Note:** This field is only available if you have the Credit Balance feature enabled and the Invoice Settlement feature disabled.  | [optional] 
**credit_memo_amount** | **decimal.Decimal** | The currency amount of all credit memos applied to this invoice. **Note:** This field is only available if you have [Invoice Settlement](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/Invoice_Settlement) enabled. The Invoice Settlement feature is generally available as of Zuora Billing Release 296 (March 2021). This feature includes Unapplied Payments, Credit and Debit Memo, and Invoice Item Settlement. If you want to enable Invoice Settlement, see [Invoice Settlement Enablement and Checklist Guide](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/Invoice_Settlement/Invoice_Settlement_Migration_Checklist_and_Guide) for more information. | [optional] 
**currency** | **str** | A currency defined in the web-based UI administrative settings. | [optional] 
**discount** | **decimal.Decimal** | the invoice discount amount. | [optional] 
**due_date** | **date** | The date by which the payment for this invoice is due, in &#x60;yyyy-mm-dd&#x60; format. | [optional] 
**e_invoice_status** | [**EInvoiceStatus**](EInvoiceStatus.md) |  | [optional] 
**e_invoice_error_code** | **str** |  | [optional] 
**e_invoice_error_message** | **str** |  | [optional] 
**e_invoice_file_id** | **str** |  | [optional] 
**id** | **str** | The unique ID of the invoice. | [optional] 
**includes_one_time** | **bool** | Specifies whether the invoice includes one-time charges. | [optional] 
**includes_recurring** | **bool** | Specifies whether the invoice includes recurring charges. | [optional] 
**includes_usage** | **bool** | Specifies whether the invoice includes usage charges. | [optional] 
**invoice_date** | **date** | The date that appears on the invoice being created. | [optional] 
**invoice_group_number** | **str** | The number of invoice group associated with the invoice.  **Note**: This field is available only if you have the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Bill_your_customers/Bill_customers_at_subscription_level/Flexible_Billing_Attributes\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Flexible Billing Attributes&lt;/a&gt; feature enabled.  | [optional] 
**invoice_number** | **str** | The unique identification number of the invoice. | [optional] 
**last_email_sent_date** | **str** | The date when the invoice was last emailed. | [optional] 
**payment_amount** | **decimal.Decimal** | The amount of payments applied to the invoice. | [optional] 
**payment_term** | **str** | The name of payment term associated with the invoice. | [optional] 
**posted_by** | **str** | The user ID of the person who moved the invoice to Posted status. | [optional] 
**posted_date** | **date** | The date when the invoice was posted. | [optional] 
**refund_amount** | **decimal.Decimal** | Specifies the amount of a refund that was applied against an earlier payment on the invoice. | [optional] 
**sequence_set_id** | **str** | The ID of the sequence set associated with the invoice. | [optional] 
**ship_to_contact_id** | **str** | The ID of the ship-to contact associated with the invoice. | [optional] 
**ship_to_contact_snapshot_id** | **str** | The ID of the ship-to contact snapshot associated with the invoice. | [optional] 
**sold_to_contact_id** | **str** | The ID of the sold-to contact associated with the invoice. | [optional] 
**sold_to_contact_snapshot_id** | **str** | The ID of the sold-to contact snapshot associated with the invoice. | [optional] 
**source** | **str** | The source of the invoice. | [optional] 
**source_id** | **str** | The ID of the invoice source. If an invoice is generated from a bill run, the value is the number of the corresponding bill run.Otherwise, the value is &#x60;null&#x60;. | [optional] 
**source_type** | **str** | The type of the invoice source. | [optional] 
**status** | [**BillingDocumentStatus**](BillingDocumentStatus.md) |  | [optional] 
**target_date** | **date** | This date is used to determine which charges are to be billed. All charges that are to be billed on this date or prior will be included in this bill run. | [optional] 
**tax_amount** | **decimal.Decimal** | The amount of taxation. | [optional] 
**tax_exempt_amount** | **decimal.Decimal** | The calculated tax amount excluded due to the exemption. | [optional] 
**tax_message** | **str** | The message that the tax engine return if it calculates the taxes of this invoice fails. | [optional] 
**tax_status** | [**TaxStatus**](TaxStatus.md) |  | [optional] 
**template_id** | **str** | The ID of the invoice template.  - If you have the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Subscriptions/Flexible_Billing_Attributes\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Flexible Billing Attributes&lt;/a&gt; feature enabled, the value of this field depends on the configuration of the invoice template.    - If you specify an invoice template at the subscription level, the value of this field is automatically populated from the corresponding subscription.   - If you do not specify any invoice template at the subscription level, the value of this field is automatically populated from the corresponding account. - If you have the Flexible Billing Attributes feature disabled, the value of this field is &#x60;null&#x60;.  | [optional] 
**transferred_to_accounting** | [**TransferredToAccountingStatus**](TransferredToAccountingStatus.md) |  | [optional] 
**updated_by_id** | **str** | The ID of the Zuora user who last updated the invoice. | [optional] 
**updated_date** | **str** | The date when the invoice was last updated. | [optional] 
**integration_id__ns** | **str** | ID of the corresponding object in NetSuite. Only available if you have installed the [Zuora Connector for NetSuite](https://www.zuora.com/connect/app/?appId&#x3D;265).  | [optional] 
**integration_status__ns** | **str** | Status of the invoice&#39;s synchronization with NetSuite. Only available if you have installed the [Zuora Connector for NetSuite](https://www.zuora.com/connect/app/?appId&#x3D;265).  | [optional] 
**sync_date__ns** | **str** | Date when the invoice was synchronized with NetSuite. Only available if you have installed the [Zuora Connector for NetSuite](https://www.zuora.com/connect/app/?appId&#x3D;265).  | [optional] 

## Example

```python
from zuora_sdk.models.invoice_response import InvoiceResponse

# TODO update the JSON string below
json = "{}"
# create an instance of InvoiceResponse from a JSON string
invoice_response_instance = InvoiceResponse.from_json(json)
# print the JSON string representation of the object
print(InvoiceResponse.to_json())

# convert the object into a dict
invoice_response_dict = invoice_response_instance.to_dict()
# create an instance of InvoiceResponse from a dict
invoice_response_from_dict = InvoiceResponse.from_dict(invoice_response_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


